wq.core
=======

wq.core provides the ``wq`` command for use by
`wq.app <https://wq.io/wq.app>`__, `wq.io <https://wq.io/wq.io>`__, and
`wq.start <https://wq.io/docs/setup>`__.

.. code:: bash

    $ wq --help

